@@ -113,9 +113,11 @@ identify_rows.tbl_sql <- function(data, vars, match = c("in", "start", "regex",
     #   "\n - where", ifelse(if_all & length(vars) > 1, "all of the", ifelse(length(vars) > 1, "at least one of the", "the")), paste0(vars, collapse = ", "), "column(s) in each record",
     #   "\n   - contains a value", match_msg, match_str, "\n"
     # )
-    rlang::inform(c("i" = "Identify records with condition(s):",
-                    "*" = glue::glue('where {ifelse(if_all & length(vars) > 1, "all of the", ifelse(length(vars) > 1, "at least one of the", "the"))} {paste0(vars, collapse = ", ")} column(s) in each record'),
-                    "*" = glue::glue('contains a value {match_msg} {match_str}')))
+    rlang::inform(c(
+      "i" = "Identify records with condition(s):",
+      "*" = glue::glue('where {ifelse(if_all & length(vars) > 1, "all of the", ifelse(length(vars) > 1, "at least one of the", "the"))} {paste0(vars, collapse = ", ")} column(s) in each record'),
+      "*" = glue::glue("contains a value {match_msg} {match_str}")
+    ))
   }
 
   # job done
@@ -128,10 +130,14 @@ identify_rows.tbl_sql <- function(data, vars, match = c("in", "start", "regex",
     #   "\nTo see the final query generated by 'dbplyr', use dplyr::show_query() on the output.",
     #   "\nTo extract the SQL string, use dbplyr::remote_query().\n"
     # )
-    rlang::inform(c("i" = "To see the final query generated by 'dbplyr', use dplyr::show_query() on the output.",
-                    "To extract the SQL string, use dbplyr::remote_query().\n"),
-                  .frequency = "once",
-                  .frequency_id = "healthdb_show_sql")
+    rlang::inform(
+      c(
+        "i" = "To see the final query generated by 'dbplyr', use dplyr::show_query() on the output.",
+        "To extract the SQL string, use dbplyr::remote_query().\n"
+      ),
+      .frequency = "once",
+      .frequency_id = "healthdb_show_sql"
+    )
   }
 
   return(q_match)
