@@ -35,9 +35,12 @@ report_n <- function(..., on, force_proceed = getOption("healthdb.force_proceed"
   rlang::check_required(on)
 
   on <- rlang::try_fetch(rlang::as_name(rlang::enquo(on)),
-                  error = function(cnd) rlang::abort("Failed to convert `on` to a variable name. It has to be a single quoted or unquoted name.", parent = cnd))
+    error = function(cnd) rlang::abort("Failed to convert `on` to a variable name. It has to be a single quoted or unquoted name.", parent = cnd)
+  )
 
-  col_nm <- purrr::map(dat, function(x) {if ("dtplyr_step" %in% class(x)) x[["vars"]] else colnames(x)})
+  col_nm <- purrr::map(dat, function(x) {
+    if ("dtplyr_step" %in% class(x)) x[["vars"]] else colnames(x)
+  })
 
   if (any(!purrr::map_lgl(col_nm, function(x) on %in% x))) stop("All data must have the ", on, " column.")
 
