@@ -1,6 +1,5 @@
 #' @export
-restrict_n.data.frame <- function(data, clnt_id, n_per_clnt, count_by = NULL, mode = c("flag", "filter"), verbose = getOption("healthdb.verbose")
-) {
+restrict_n.data.frame <- function(data, clnt_id, n_per_clnt, count_by = NULL, mode = c("flag", "filter"), verbose = getOption("healthdb.verbose")) {
   mode <- rlang::arg_match0(mode, c("flag", "filter"))
 
   # as_name(enquo(arg)) converts both quoted and unquoted column name to string
@@ -20,7 +19,7 @@ restrict_n.data.frame <- function(data, clnt_id, n_per_clnt, count_by = NULL, mo
   } else {
     n_filter <- dt[, list(temp_keep_rid = .I[.N >= n_per_clnt]), by = clnt_id_nm]$temp_keep_rid
   }
-  #browser()
+  # browser()
 
   dt[, flag_restrict_n := ifelse(.I %in% n_filter, 1, 0)]
 
