@@ -30,7 +30,7 @@ hosp_df <- make_test_dat(vals_kept = c(glue("F{10:19}"), glue("F{100:199}"), noi
 hosp_df %>% head()
 
 # convert Date to numeric to be consistent with claim_db
-hosp_df <- hosp_df %>% 
+hosp_df <- hosp_df %>%
   mutate(dates = julian(dates))
 
 ## ----eval=FALSE---------------------------------------------------------------
@@ -112,15 +112,15 @@ result_df <- result_df %>% mutate(year = lubridate::year(as.Date(dates, origin =
 
 # note that keys must be present in all tables
 fetch_var(result_df,
-          keys = c(clnt_id, year),
-          linkage = list(
-            # the formula means from_table ~ get_variable
-            # |clnt_id means matching on clnt_id only
-            age_tab ~ c(age, sex) | clnt_id,
-            address_tab ~ area_code
-          )
+  keys = c(clnt_id, year),
+  linkage = list(
+# the formula means from_table ~ get_variable
+# |clnt_id means matching on clnt_id only
+age_tab ~ c(age, sex) | clnt_id,
+address_tab ~ area_code
+  )
 ) %>%
-  select(uid, clnt_id, dates, age, sex, area_code) %>% 
+  select(uid, clnt_id, dates, age, sex, area_code) %>%
   head()
 
 ## -----------------------------------------------------------------------------
@@ -176,10 +176,11 @@ bind_source(result_list,
 
 ## -----------------------------------------------------------------------------
 pool_case(result_list,
-          def = sud_def,
-          # your could skip summary with output_lvl = "raw"
-          output_lvl = "clnt",
-          # include records only from sources having valid records, see function documentation for more detail and other options
-          include_src = "has_valid",
-          force_proceed = TRUE)
+  def = sud_def,
+  # your could skip summary with output_lvl = "raw"
+  output_lvl = "clnt",
+  # include records only from sources having valid records, see function documentation for more detail and other options
+  include_src = "has_valid",
+  force_proceed = TRUE
+)
 
